Options

Don't forget to save settings after changing

| Note: you can quickly toggle some of these settings via the context menu on any page (typically need to reload the page to see the effect).

Troubleshoot
See troubleshooting guide/help
If you messed up any extension settings, you can check src/options.js. Alternatively, use 'reset settings' button in the bottom of the page.
Make sure to regularly export/backup settings (after saving first):
(there is no import yet, will be added later)
Sources
Backend settings Don't forget to setup & run the backend first.
However, you can leave it empty if you want to use in-browser visits only.
In-browser sources Note that these sources aren't typically as useful as the backend ones, and support for them is still limited (see issues/120)
Browser bookmarks

| Enable

Browser history

| Enable

History results limit (controls this parameter). Set it to lower value if you suspect browser history search is causing slowdowns for you (pretty unlikely though)
Sidebar

| Detect and linkify URLs in the sidebar
| Always show sidebar (experimental)

'Mark visited' feature

| Mark visited links on page load (experimental, but highly recommended to try)

Exclude links from being marked as visited:
Other behaviour

| Highlight contexts/annotations
| Popup notification when link has contexts (may be spammy)
| Verbose errors (for debugging, may result in notification spam)

Global excludes
Global excluding might be useful for several purposes: - less distraction: if you don't want to be notified of specific pages (e.g. they are too broad, like "google.com") - privacy: to avoid passing sensitive information to the extension (e.g. from your bank website) - performance: if you experience problems with certain pages NOTE: you can also exclude links from the context menu.
Globally excluded links and domains:
Supported formats: - `domain.name`, e.g.: `web.telegram.org` Will exclude whole Telegram website. - `http://exact/match`, e.g.: `http://github.com` Will only exclude Github main page. Subpages will still work. - `/regul.r.*expression/`, e.g.: `/github.*/yourusername/` Quick way to exclude your own Github repostitories.

External exclude lists:
In addition to specific excludes above, you can specify links to external filter lists. They will be autoupdated every 3 days. Spec format (Json):

    [
        ["name (arbitrary)", "link"],
        ["name2"           , "link 2", "optional comment"]
    ]

Style settings (CSS)
Not very documented at the moment; you can use your browser devtools to experiment
Deprecated/misc settings
Source map (json):
Can be used to rename the sources
Sidebar style (DEPRECATED!)
If you had any settings here, please move them to the field above